var languageNames = {
"en-US": "Inglês (EUA)",
"am": "Amárico",
"ar": "Árabe",
"ast": "Asturiano",
"bg": "Búlgaro",
"bn": "Bengali",
"bn-IN": "Bengali (Índia)",
"bo": "Tibetano",
"bs": "Bósnio",
"ca": "Catalão",
"ca-valencia": "Valenciano",
"cs": "Tcheco",
"da": "Dinamarquês",
"de": "Alemão",
"dz": "Dzongkha",
"el": "Grego",
"en-GB": "Inglês (GB)",
"en-ZA": "Inglês (RSA)",
"eo": "Esperanto",
"es": "Espanhol",
"et": "Estoniano",
"eu": "Basco",
"fi": "Finlandês",
"fr": "Francês",
"gl": "Galego",
"gu": "Gujarate",
"he": "Hebraico",
"hi": "Hindi",
"hr": "Croata",
"hu": "Húngaro",
"id": "Indonésio",
"is": "Islandẽs",
"it": "Italiano",
"ja": "Japonês",
"ka": "Georgiano",
"km": "Kmer",
"ko": "Coreano",
"lo": "Laociano",
"lt": "Lituano",
"lv": "Letão",
"mk": "Macedônio",
"nb": "Norueguês Bokmål",
"ne": "Nepalês",
"nl": "Holandês",
"nn": "Norueguês Nynorsk",
"om": "Oromo",
"pl": "Polonês",
"pt": "Português",
"pt-BR": "Português do Brasil",
"ro": "Romeno",
"ru": "Russo",
"si": "Sinhala",
"sid": "Sidama",
"sk": "Eslovaco",
"sl": "Esloveno",
"sq": "Albanês",
"sv": "Sueco",
"ta": "Tamil",
"tg": "Tajique",
"tr": "Turco",
"ug": "Uigur",
"uk": "Ucraniano",
"vi": "Vietnamês",
"zh-CN": "Chinês (Simplificado)",
"zh-TW": "Chinês (Tradicional)",
};
